@@ -89,6 +89,7 @@ class TestServer(compute_fakes.TestComputev2):
 class TestServerCreate(TestServer):
 
     columns = (
+        'OS-EXT-STS:power_state',
         'addresses',
         'flavor',
         'id',
@@ -100,6 +101,8 @@ class TestServerCreate(TestServer):
 
     def datalist(self):
         datalist = (
+            server._format_servers_list_power_state(
+                getattr(self.new_server, 'OS-EXT-STS:power_state')),
             '',
             self.flavor.name + ' (' + self.new_server.flavor.get('id') + ')',
             self.new_server.id,
@@ -146,7 +149,6 @@ class TestServerCreate(TestServer):
             ('server_name', self.new_server.name),
         ]
 
-        # Missing required args should bail here
         self.assertRaises(utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
@@ -1231,6 +1233,101 @@ class TestServerShelve(TestServer):
         self.run_method_with_servers('shelve', 3)
 
 
+class TestServerShow(TestServer):
+
+    def setUp(self):
+        super(TestServerShow, self).setUp()
+
+        self.image = image_fakes.FakeImage.create_one_image()
+        self.flavor = compute_fakes.FakeFlavor.create_one_flavor()
+        server_info = {
+            'image': {'id': self.image.id},
+            'flavor': {'id': self.flavor.id},
+            'tenant_id': 'tenant-id-xxx',
+            'networks': {'public': ['10.20.30.40', '2001:db8::f']},
+        }
+        # Fake the server.diagnostics() method. The return value contains http
+        # response and data. The data is a dict. Sincce this method itself is
+        # faked, we don't need to fake everything of the return value exactly.
+        resp = mock.Mock()
+        resp.status_code = 200
+        server_method = {
+            'diagnostics': (resp, {'test': 'test'}),
+        }
+        self.server = compute_fakes.FakeServer.create_one_server(
+            attrs=server_info, methods=server_method)
+
+        # This is the return value for utils.find_resource()
+        self.servers_mock.get.return_value = self.server
+        self.cimages_mock.get.return_value = self.image
+        self.flavors_mock.get.return_value = self.flavor
+
+        # Get the command object to test
+        self.cmd = server.ShowServer(self.app, None)
+
+        self.columns = (
+            'OS-EXT-STS:power_state',
+            'addresses',
+            'flavor',
+            'id',
+            'image',
+            'name',
+            'networks',
+            'project_id',
+            'properties',
+        )
+
+        self.data = (
+            'Running',
+            'public=10.20.30.40, 2001:db8::f',
+            self.flavor.name + " (" + self.flavor.id + ")",
+            self.server.id,
+            self.image.name + " (" + self.image.id + ")",
+            self.server.name,
+            {'public': ['10.20.30.40', '2001:db8::f']},
+            'tenant-id-xxx',
+            '',
+        )
+
+    def test_show_no_options(self):
+        arglist = []
+        verifylist = []
+
+        self.assertRaises(utils.ParserException, self.check_parser,
+                          self.cmd, arglist, verifylist)
+
+    def test_show(self):
+        arglist = [
+            self.server.name,
+        ]
+        verifylist = [
+            ('diagnostics', False),
+            ('server', self.server.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_show_diagnostics(self):
+        arglist = [
+            '--diagnostics',
+            self.server.name,
+        ]
+        verifylist = [
+            ('diagnostics', True),
+            ('server', self.server.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.assertEqual(('test',), columns)
+        self.assertEqual(('test',), data)
+
+
 class TestServerStart(TestServer):
 
     def setUp(self):
@@ -1449,14 +1546,12 @@ class TestServerGeneral(TestServer):
     @mock.patch('openstackclient.common.utils.find_resource')
     def test_prep_server_detail(self, find_resource):
         # Setup mock method return value. utils.find_resource() will be called
-        # twice in _prep_server_detail():
-        # - The first time, return image info.
-        # - The second time, return flavor info.
+        # three times in _prep_server_detail():
+        # - The first time, return server info.
+        # - The second time, return image info.
+        # - The third time, return flavor info.
         _image = image_fakes.FakeImage.create_one_image()
         _flavor = compute_fakes.FakeFlavor.create_one_flavor()
-        find_resource.side_effect = [_image, _flavor]
-
-        # compute_client.servers.get() will be called once, return server info.
         server_info = {
             'image': {u'id': _image.id},
             'flavor': {u'id': _flavor.id},
@@ -1465,7 +1560,7 @@ class TestServerGeneral(TestServer):
             'links': u'http://xxx.yyy.com',
         }
         _server = compute_fakes.FakeServer.create_one_server(attrs=server_info)
-        self.servers_mock.get.return_value = _server
+        find_resource.side_effect = [_server, _image, _flavor]
 
         # Prepare result data.
         info = {
@@ -1476,6 +1571,8 @@ class TestServerGeneral(TestServer):
             'image': u'%s (%s)' % (_image.name, _image.id),
             'project_id': u'tenant-id-xxx',
             'properties': '',
+            'OS-EXT-STS:power_state': server._format_servers_list_power_state(
+                getattr(_server, 'OS-EXT-STS:power_state')),
         }
 
         # Call _prep_server_detail().
